@@ -17,7 +17,7 @@ extends 'App::Sqitch::Engine';
 sub dbh; # required by DBIEngine;
 with 'App::Sqitch::Role::DBIEngine';
 
-our $VERSION = '0.990';
+our $VERSION = '0.991';
 
 has registry_uri => (
     is       => 'ro',
@@ -229,7 +229,7 @@ sub finish_work {
 }
 
 sub _no_table_error  {
-    return $DBI::errstr =~ /^\Qno such table:/;
+    return $DBI::errstr && $DBI::errstr =~ /^\Qno such table:/;
 }
 
 sub _regex_op { 'REGEXP' }
