@@ -162,6 +162,14 @@ sub get {
     return $self->{list}[ $idx ];
 }
 
+sub contains {
+    my ( $self, $name ) = @_;
+    return defined (  $name =~ /@/
+        ? $self->index_of($name)
+        : $self->first_index_of($name)
+    );
+}
+
 sub find {
     my ( $self, $name ) = @_;
     my $idx   = $name =~ /@/
@@ -190,8 +198,8 @@ sub append {
         }
     }
 
-    $lookup->{'@HEAD'} = [$#$list];
-    $lookup->{'@ROOT'} = [0];
+    $lookup->{'HEAD'} = $lookup->{'@HEAD'} = [$#$list];
+    $lookup->{'ROOT'} = $lookup->{'@ROOT'} = [0];
 
     return $self;
 }
@@ -372,6 +380,13 @@ described for C<index_of()>. An exception will be thrown if more than one change
 goes by a specified name. As such, it is best to specify it as unambiguously
 as possible: as a tag name, a tag-qualified change name, or an ID.
 
+=head3 C<contains>
+
+  say 'Yes!' if $plan->contains('6c2f28d125aff1deea615f8de774599acf39a7a1');
+
+Like C<index_of()>, but never throws an exception, and returns true if the
+plan contains the specified change, and false if it does not.
+
 =head3 C<find>
 
   my $change = $changelist->find($id);
