@@ -10,13 +10,21 @@ our $MOCK = Test::MockModule->new('App::Sqitch');
 
 my @mocked = qw(
     trace
+    trace_literal
     debug
+    debug_literal
     info
+    info_literal
     comment
+    comment_literal
     emit
+    emit_literal
     vent
+    vent_literal
     warn
+    warn_literal
     page
+    page_literal
     prompt
     ask_y_n
 );
